common

package
v1.6.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Version = "dev"
	Commit  = "none"
	Date    = "unknown"
)

Version information set by ldflags during build

Functions

func AddCommonFlags

func AddCommonFlags(cmd *cobra.Command, verbose, debug *bool)

AddCommonFlags adds verbose and debug flags that are shared by all commands

func SetupLogger

func SetupLogger(verbose, debug bool) *log.Logger

SetupLogger creates a new logger with the given verbose and debug settings

Types

This section is empty.

Jump to